'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _redux = require('redux');

var _reactRedux = require('react-redux');

var _styles = require('material-ui/styles');

var _List = require('material-ui/List');

var _List2 = _interopRequireDefault(_List);

var _Divider = require('material-ui/Divider');

var _Divider2 = _interopRequireDefault(_Divider);

var _Settings = require('material-ui-icons/Settings');

var _Settings2 = _interopRequireDefault(_Settings);

var _Paper = require('material-ui/Paper');

var _Paper2 = _interopRequireDefault(_Paper);

var _reactIntl = require('react-intl');

var _filter_fields = require('../../selectors/filter_fields');

var _filter_fields2 = _interopRequireDefault(_filter_fields);

var _field_analysis = require('../../selectors/field_analysis');

var _field_analysis2 = _interopRequireDefault(_field_analysis);

var _field_mapping = require('../../selectors/field_mapping');

var _field_mapping2 = _interopRequireDefault(_field_mapping);

var _color_index = require('../../selectors/color_index');

var _color_index2 = _interopRequireDefault(_color_index);

var _action_creators = require('../../action_creators');

var _discrete_filter = require('./discrete_filter');

var _discrete_filter2 = _interopRequireDefault(_discrete_filter);

var _date_filter = require('./date_filter');

var _date_filter2 = _interopRequireDefault(_date_filter);

var _constants = require('../../constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = {
  root: {
    minWidth: 300,
    flex: 1,
    overflowY: 'auto',
    zIndex: 2,
    // backgroundColor: 'white',
    '@media print': {
      display: 'none'
    }
  },
  list: {
    paddingTop: 0
  },
  listItemInner: {
    padding: 0
  },
  listItemText: {
    padding: '0 16px 0 0'
  },
  listIcon: {
    fill: 'rgb(117, 117, 117)',
    left: 0,
    top: 0,
    margin: '12px',
    position: 'absolute'
  },
  link: {
    color: '#000',
    display: 'block',
    padding: '16px 16px 16px 48px',
    textDecoration: 'none'
  }
};

var messages = (0, _reactIntl.defineMessages)({
  changeFilters: {
    'id': 'filter.change',
    'defaultMessage': 'Change Filters\u2026'
  }
});

var FilterPane = function FilterPane(_ref) {
  var classes = _ref.classes,
      _ref$filters = _ref.filters,
      filters = _ref$filters === undefined ? {} : _ref$filters,
      _ref$fieldStats = _ref.fieldStats,
      fieldStats = _ref$fieldStats === undefined ? {} : _ref$fieldStats,
      _ref$filterFields = _ref.filterFields,
      filterFields = _ref$filterFields === undefined ? [] : _ref$filterFields,
      coloredField = _ref.coloredField,
      colorIndex = _ref.colorIndex,
      _ref$onUpdateFilter = _ref.onUpdateFilter,
      onUpdateFilter = _ref$onUpdateFilter === undefined ? function (x) {
    return x;
  } : _ref$onUpdateFilter,
      _ref$onClickSettings = _ref.onClickSettings,
      onClickSettings = _ref$onClickSettings === undefined ? function (x) {
    return x;
  } : _ref$onClickSettings;
  return _react2.default.createElement(
    _Paper2.default,
    { className: classes.root, elevation: 3 },
    _react2.default.createElement(
      _List2.default,
      { className: classes.list, dense: true },
      filterFields.map(function (f) {
        var field = fieldStats.properties[f] || {};
        var filter = filters[f];
        switch (field.filterType) {
          case _constants.FILTER_TYPE_DISCRETE:
            return _react2.default.createElement(
              'div',
              { key: f },
              _react2.default.createElement(_discrete_filter2.default, {
                fieldName: f,
                checked: filter ? filter.in : field.values.map(function (v) {
                  return v.value;
                }),
                values: field.values,
                colored: coloredField === f || coloredField + '.0' === f,
                colorIndex: colorIndex,
                onUpdate: onUpdateFilter }),
              _react2.default.createElement(_Divider2.default, null)
            );
          case _constants.FILTER_TYPE_RANGE:
            return;
          case _constants.FILTER_TYPE_TEXT:
            return;
          case _constants.FILTER_TYPE_DATE:
            return _react2.default.createElement(
              'div',
              { key: f },
              _react2.default.createElement(_date_filter2.default, {
                fieldName: f,
                filter: filter,
                min: filter ? filter['>='] : field.valueStats.min,
                max: filter ? filter['<='] : field.valueStats.max,
                valueMin: field.valueStats.min,
                valueMax: field.valueStats.max,
                onUpdate: onUpdateFilter }),
              _react2.default.createElement(_Divider2.default, null)
            );
        }
      }),
      _react2.default.createElement(
        _List.ListItem,
        { button: true, onClick: onClickSettings },
        _react2.default.createElement(
          _List.ListItemIcon,
          null,
          _react2.default.createElement(_Settings2.default, null)
        ),
        _react2.default.createElement(_List.ListItemText, {
          classes: { root: classes.listItemText },
          primary: _react2.default.createElement(_reactIntl.FormattedMessage, messages.changeFilters)
        })
      )
    )
  );
};

FilterPane.propTypes = {
  filters: _propTypes2.default.object,
  fieldStats: _propTypes2.default.object.isRequired,
  filterFields: _propTypes2.default.arrayOf(_propTypes2.default.string).isRequired,
  /* called with valid mapbox-gl filter when updated */
  onUpdateFilter: _propTypes2.default.func,
  onClickSettings: _propTypes2.default.func
};

function mapStateToProps(state) {
  return {
    filters: state.filters,
    filterFields: (0, _filter_fields2.default)(state),
    fieldStats: (0, _field_analysis2.default)(state),
    coloredField: (0, _field_mapping2.default)(state).color,
    colorIndex: (0, _color_index2.default)(state)
  };
}

function mapDispatchToProps(dispatch) {
  return {
    onUpdateFilter: function onUpdateFilter(filter) {
      return dispatch((0, _action_creators.updateFilter)(filter));
    },
    onClickSettings: function onClickSettings() {
      return dispatch((0, _action_creators.openSettings)('filters'));
    }
  };
}

exports.default = (0, _redux.compose)((0, _reactRedux.connect)(mapStateToProps, mapDispatchToProps), (0, _styles.withStyles)(styles))(FilterPane);
//# sourceMappingURL=index.js.map