'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _styles = require('material-ui/styles');

var _Typography = require('material-ui/Typography');

var _Typography2 = _interopRequireDefault(_Typography);

var _image = require('../image');

var _image2 = _interopRequireDefault(_image);

var _marker_icon = require('./marker_icon');

var _marker_icon2 = _interopRequireDefault(_marker_icon);

var _formatted_value = require('../shared/formatted_value');

var _formatted_value2 = _interopRequireDefault(_formatted_value);

var _table = require('../shared/table');

var _table2 = _interopRequireDefault(_table);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var styles = {
  root: {
    backgroundColor: 'white'
  },
  header: {
    display: 'flex',
    padding: 16,
    alignItems: 'center'
  },
  avatar: {
    flex: '0 0 auto',
    marginRight: 16
  },
  headerContent: {
    flex: '1 1 auto'
  },
  media: {
    position: 'relative',
    height: '100%',
    padding: '67% 0 0 0'
  },
  img: {
    width: '100%',
    height: '100%',
    top: 0,
    left: 0,
    position: 'absolute',
    objectFit: 'cover'
  }
};

var ReportFeature = function ReportFeature(_ref) {
  var label = _ref.label,
      classes = _ref.classes,
      colorIndex = _ref.colorIndex,
      feature = _ref.feature,
      fieldAnalysis = _ref.fieldAnalysis,
      fieldMapping = _ref.fieldMapping,
      fieldOrder = _ref.fieldOrder,
      settings = _ref.settings,
      visibleFields = _ref.visibleFields;

  var props = feature.properties;
  var media = props[fieldMapping.media];
  var title = props[fieldMapping.title];
  var subtitle = props[fieldMapping.subtitle];
  var color = colorIndex[props[fieldMapping.color]] || props[fieldMapping.color] && colorIndex[props[fieldMapping.color][0]];
  var analysisProps = fieldAnalysis.properties;
  var titleType = analysisProps[fieldMapping.title] && analysisProps[fieldMapping.title].type;
  var subtitleType = analysisProps[fieldMapping.subtitle] && analysisProps[fieldMapping.subtitle].type;

  return _react2.default.createElement(
    'div',
    { className: classes.root },
    _react2.default.createElement(
      'div',
      { className: classes.header },
      _react2.default.createElement(
        'div',
        { className: classes.avatar },
        _react2.default.createElement(_marker_icon2.default, { color: color, className: classes.markerIcon, label: label })
      ),
      _react2.default.createElement(
        'div',
        { className: classes.headerContent },
        _react2.default.createElement(
          _Typography2.default,
          { type: 'title' },
          _react2.default.createElement(_formatted_value2.default, { value: title, type: titleType })
        ),
        _react2.default.createElement(
          _Typography2.default,
          { type: 'subheading' },
          _react2.default.createElement(_formatted_value2.default, { value: subtitle, type: subtitleType })
        )
      )
    ),
    media && _react2.default.createElement(
      'div',
      { className: classes.media },
      _react2.default.createElement(_image2.default, { className: classes.img, src: media })
    ),
    _react2.default.createElement(_table2.default, {
      feature: feature,
      fieldAnalysis: fieldAnalysis,
      fieldOrder: fieldOrder,
      visibleFields: visibleFields,
      coordFormat: settings.coordFormat
    })
  );
};

exports.default = (0, _styles.withStyles)(styles)(ReportFeature);
//# sourceMappingURL=feature.js.map