'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filters = exports.features = exports.mapboxFilter = exports.fieldMapping = exports.mapViewFeature = undefined;

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// GeoJSON passed to the map view must be a FeatureCollection
// of point features.
// We need to ensure each feature has an id so we can handle
// callbacks for when a marker is clicked or hovered.
var mapViewFeature = exports.mapViewFeature = _propTypes2.default.shape({
  id: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]).isRequired,
  type: _propTypes2.default.oneOf(['Feature']),
  geometry: _propTypes2.default.oneOfType([_propTypes2.default.oneOf([null]), _propTypes2.default.shape({
    type: _propTypes2.default.oneOf(['Point']).isRequired,
    coordinates: _propTypes2.default.array.isRequired
  })]).isRequired
});

var fieldMapping = exports.fieldMapping = _propTypes2.default.shape({
  media: _propTypes2.default.string,
  mediaType: _propTypes2.default.string,
  title: _propTypes2.default.string.isRequired,
  subtitle: _propTypes2.default.string
});

/* See https://www.mapbox.com/mapbox-gl-style-spec/#types-filter */
/* We only support a specific subset of the mapbox array spec */
var mapboxFilter = exports.mapboxFilter = _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.oneOf(['all']), _propTypes2.default.arrayOf(_propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number, _propTypes2.default.array]))]));

var features = exports.features = _propTypes2.default.arrayOf(_propTypes2.default.shape({
  type: _propTypes2.default.oneOf(['Feature']).isRequired,
  geometry: _propTypes2.default.oneOfType([_propTypes2.default.oneOf([null]), _propTypes2.default.shape({
    type: _propTypes2.default.oneOf(['Point']).isRequired,
    coordinates: _propTypes2.default.array.isRequired
  })]).isRequired,
  properties: _propTypes2.default.object
})).isRequired;

/**
 * Our filter structure is similar to mapbox filters but we index
 * by key and then expression. We only allow filters to combined
 * with logical AND using the "all" expression.
 * @example
 * ```
 * var filter = {
 *   name: {
 *     'in': ['bob', 'susan']
 *   },
 *   age: {
 *     '<=': 50,
 *     '>=': 30
 *   }
 * }
 */
var filters = exports.filters = _propTypes2.default.objectOf(_propTypes2.default.objectOf(_propTypes2.default.arrayOf(_propTypes2.default.string)));
//# sourceMappingURL=prop_types.js.map